
.. _algorithms/tour:

Tour
****

Algorithms
----------

The travelling salesman problem (TSP) asks the following question: "Given a list of cities and
the distances between each pair of cities, what is the shortest possible route that visits each
city exactly once and returns to the origin city?".

The following algorithms are available:

.. automodule:: jgrapht.algorithms.tour
   :members:

Types
-----

Tours are represented with instances of :py:class:`.GraphPath`.

.. autoclass:: jgrapht.types.GraphPath
   :members:
   :noindex: